<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Darryldecode\Cart\Facades\CartFacade as Cart;
use App\Models\Product;

class CartController extends Controller
{
    public function addToCart(Request $request)
    {
        $productId = $request->input('product_id');

        // Retrieve product details from the database by product ID
        $product = Product::find($productId);

        if (!$product) {
            return response()->json(['error' => 'Product not found'], 404);
        }

        $userID = 2;

        try {
            // Add the product to the cart
            \Cart::session($userID)->add([
                'id' => $product->id,
                'name' => $product->name,
                'price' => $product->price,
                'quantity' => 1,
                'attributes' => [],  // You can add additional attributes if needed
                'associatedModel' => $product,
            ]);

            return response()->json(['success' => true]);
        } catch (\Darryldecode\Cart\Exceptions\InvalidItemException $e) {
            return response()->json(['error' => $e->getMessage()], 422); // 422 is the Unprocessable Entity HTTP status code
        }
    }

    public function updateCart(Request $request)
    {
        $productId = $request->input('product_id');
        $quantity = $request->input('quantity');

        $userID = 2;
        \Cart::session($userID)->update($productId, array(
            'quantity' => array(
                'relative' => false,
                'value' => $quantity
            ),
        ));
        return response()->json(['success' => true]);
    }

    public function showCart()
    {

        $products = Product::all();
        $userID = 2;
        $cartContent = \Cart::session($userID)->getContent();
      
        $cartCount = $cartContent->count();

        $total = \Cart::getTotal();
        
        $wishlistItems = Cart::session('wishlist')->getContent();
        $wishlistCount = $wishlistItems->count();
        $wishlistProductIds = $wishlistItems->pluck('id')->toArray();

        return view('welcome')
            ->with('products', $products)
            ->with('wishlistProductIds', $wishlistProductIds)
            ->with('cartCount', $cartCount)
            ->with('wishlistCount', $wishlistCount)
            ->with('cartContent', $cartContent)->with('total', $total);
    }

    public function removeCart(Request $request)
    {
        $productId = $request->input('product_id');

        $userID = 2;
        \Cart::session($userID)->remove($productId);
        return response()->json(['success' => true]);
    }

    public function clearCart(Request $request)
    {
        $userID = 2;
        \Cart::session($userID)->clear();

        return response()->json(['success' => true]);
    }
}
