<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">

<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <title>Laravel</title>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/css/bootstrap.min.css" integrity="sha384-T3c6CoIi6uLrA9TneNEoa7RxnatzjcDSCmG1MXxSR1GAsXEV/Dwwykc2MPK8M2HN" crossorigin="anonymous">
    <!-- Fonts -->
    <link rel="preconnect" href="https://fonts.bunny.net">
    <link href="https://fonts.bunny.net/css?family=figtree:400,600&display=swap" rel="stylesheet" />
    <style>
        .product-container {
            background-color: #fad875;
            padding: 30px 30px 15px 30px;
        }
    </style>
</head>

<body>
    <div class="container">
        <nav class="navbar navbar-light bg-light">
            <div class="container-fluid">
                <h3>Laravel Cart</h3>
                <div class="d-flex">
                    <a href="/" class="mx-3 text-decoration-none"><img class="mx-1" src="{{ asset('images/shopping-cart.svg') }}"> <span class="text-dark">{{ $cartCount }}</span></a>
                    <a href="/wishlist" class="text-decoration-none">View Wishlist<span class="text-dark">({{ $wishlistCount }})</span></a>
                </div>
            </div>
        </nav>
        <h1 class="text-center mb-3 mt-5">All Products</h1>
        <div class="product-container">
            <table class="table table-bordered">
                <thead>
                    <tr>
                        <th scope="col" style="width: 50%;">Product Name</th>
                        <th scope="col" style="width: 15%;" class="text-center">Quantity</th>
                        <th scope="col" style="width: 15%;" class="text-end">Price</th>
                        <th scope="col" class="text-center">Action</th>
                    </tr>
                </thead>
                <tbody>

                    @foreach ($products as $k => $productDetails)
                    <tr>
                        <td>{{ $productDetails['name'] }}</td>
                        <td class="text-center">
                            1
                        </td>
                        <td class="text-end">${{ number_format($productDetails['price'],2) }}</td>
                        <td class="text-center"><button type="button" class="btn btn-warning add-to-cart-btn cursor-pointer" data-product-id="{{ $productDetails['id'] }}"><span class="add-text">Add to Cart</span> <span class="d-none adding-text"> Adding</span> <span class="d-none added-text"> Added</span></button>

                        </td>
                    </tr>
                    @endforeach

                </tbody>

            </table>
        </div>
        <div class="mt-5">
            <div class="d-flex justify-content-between">
                <h2>My Cart</h2>
                <button type="button" class="btn btn-danger mb-3 clear-cart"><span class="clear-text">Clear Cart</span><span class="d-none clearing-text"> Clearing</span> <span class="d-none cleared-text"> Cleared</span></button>
            </div>
            <table class="table table-bordered">
                <thead>
                    <tr>
                        <th style="width: 40%;">Product Name</th>
                        <th class="text-center" style="width: 10%;">Quantity</th>
                        <th class="text-end" style="width: 15%;">Price</th>
                        <th class="text-end" style="width: 15%;">Sub Total</th>
                        <th class="text-center">Action</th>
                    </tr>
                </thead>
                <tbody>

                    @foreach($cartContent as $item)
                    <tr>
                        <td>{{ $item->name }}</td>
                        <td class="text-center">
                            <div class="input-group d-flex justify-content-center"><input type="number" min="1" class="form-control quantity-input text-center" value="{{ $item->quantity }}"></div>
                            <a href="javascript:;" class="update-btn cursor-pointer text-decoration-none" data-product-id="{{ $item->id }}"><span class="update-text">Update</span><span class="d-none updating-text"> Updating</span> <span class="d-none updated-text"> Update</span></a>
                        </td>
                        <td class="text-end">${{ number_format($item->price,2) }}</td>
                        <td class="text-end">${{ number_format($item->quantity * $item->price,2)}}</td>
                        <td class="text-center">
                            @if (!in_array($item->id, $wishlistProductIds))
                            <button type="button" class="btn btn-outline-primary add-to-wishlist" data-product-id="{{ $item->id }}"><span class="add-text">Add to wishlist</span><span class="d-none adding-text"> Adding</span> <span class="d-none added-text"> Added</span></button>
                            @endif
                            <button type="button" class="btn btn-outline-danger remove-btn" data-product-id="{{ $item->id }}"><span class="remove-text">Remove</span><span class="d-none removing-text"> Removing</span> <span class="d-none removed-text"> Removed</span></button>
                        </td>
                    </tr>
                    @endforeach

                    <tr>
                        <th colspan="3" class="text-end">Total</th>
                        <td class="text-end">${{ number_format($total,2) }}</td>
                        <td></td>
                    <tr>

                </tbody>
            </table>
        </div>
    </div>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script>
        $('.add-to-cart-btn').on('click', function() {
            var button = $(this);
            var productId = button.data('product-id');

            button.find('.add-text').addClass('d-none');
            button.find('.adding-text').removeClass('d-none');

            // Make an AJAX request to add the product to the cart
            $.ajax({
                type: 'POST',
                url: '{{ route('addToCart') }}',
                data: {
                    product_id: productId,
                    _token: '{{ csrf_token() }}',
                },
                success: function(response) {
                    button.find('.adding-text').addClass('d-none');
                    button.find('.added-text').removeClass('d-none');
                    location.reload();
                },
                error: function(error) {
                    console.error('Error adding product to cart:', error);
                }
            });
        });

        $('.update-btn').on('click', function() {
            var button = $(this);
            var productId = button.data('product-id');
            var quantity = button.closest('td').find('.quantity-input').val();

            button.find('.update-text').addClass('d-none');
            button.find('.updating-text').removeClass('d-none');

            // Make an AJAX request to update the product to the cart
            $.ajax({
                type: 'POST',
                url: '{{ route('updateCart') }}',
                data: {
                    product_id: productId,
                    quantity: quantity,
                    _token: '{{ csrf_token() }}',
                },
                success: function(response) {
                    button.find('.updating-text').addClass('d-none');
                    button.find('.updated-text').removeClass('d-none');
                    location.reload();
                },
                error: function(error) {
                    console.error('Error updating product to cart:', error);
                }
            });
        });

        $('.remove-btn').on('click', function() {
            var button = $(this);
            var productId = button.data('product-id');

            button.find('.remove-text').addClass('d-none');
            button.find('.removing-text').removeClass('d-none');

            // Make an AJAX request to remove the product to the cart
            $.ajax({
                type: 'POST',
                url: '{{ route('removeCart') }}',
                data: {
                    product_id: productId,
                    _token: '{{ csrf_token() }}',
                },
                success: function(response) {
                    button.find('.removing-text').addClass('d-none');
                    button.find('.removed-text').removeClass('d-none');
                    location.reload();
                },
                error: function(error) {
                    console.error('Error adding product to cart:', error);
                }
            });
        });

        $('.clear-cart').on('click', function() {
            var button = $(this);
            if (confirm('Are you sure you want to clear the cart?')) {
                button.find('.clear-text').addClass('d-none');
                button.find('.clearing-text').removeClass('d-none');
                // Make an AJAX request to clear the product to the cart
                $.ajax({
                    type: 'POST',
                    url: '{{ route('clearCart') }}',
                    data: {
                        _token: '{{ csrf_token() }}',
                    },
                    success: function(response) {
                        button.find('.clearing-text').addClass('d-none');
                        button.find('.cleared-text').removeClass('d-none');
                        location.reload();
                    },
                    error: function(error) {
                        console.error('Error adding product to cart:', error);
                    }
                });
            }
        });

        $('.add-to-wishlist').on('click', function() {
            var button = $(this);
            var productId = button.data('product-id');
            var quantity = button.closest('tr').find('.quantity-input').val();
            button.find('.add-text').addClass('d-none');
            button.find('.adding-text').removeClass('d-none');
            $.ajax({
                type: 'POST',
                url: '{{ route('addToWishlist') }}',
                data: {
                    product_id: productId,
                    quantity: quantity,
                    _token: '{{ csrf_token() }}',
                },
                success: function(response) {
                    button.find('.adding-text').addClass('d-none');
                    button.find('.added-text').removeClass('d-none');
                    // Handle success response if needed
                    if (response.redirect_url) {
                        // Perform the redirect
                        window.location.href = response.redirect_url;
                    }
                },
                error: function(xhr, status, error) {
                    console.error('Error adding product to wishlist:', error);
                    console.log(xhr.responseText); // Log the entire response for more details
                }
            });
        });
    </script>
</body>

</html>