<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">

<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <title>Laravel</title>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/css/bootstrap.min.css" integrity="sha384-T3c6CoIi6uLrA9TneNEoa7RxnatzjcDSCmG1MXxSR1GAsXEV/Dwwykc2MPK8M2HN" crossorigin="anonymous">
    <!-- Fonts -->
    <link rel="preconnect" href="https://fonts.bunny.net">
    <link href="https://fonts.bunny.net/css?family=figtree:400,600&display=swap" rel="stylesheet" />
    <style>
        .product-container {
            background-color: #fad875;
            padding: 30px 30px 15px 30px;
        }
    </style>
</head>

<body>
    <div class="container">
        <nav class="navbar navbar-light bg-light">
            <div class="container-fluid">
                <h3>Laravel Cart</h3>
                <div class="d-flex">
                    <a href="/" class="mx-3 text-decoration-none"><img class="mx-1" src="{{ asset('images/shopping-cart.svg') }}"> <span class="text-dark">{{ $cartCount }}</span></a>
                    <a href="/wishlist" class="text-decoration-none">View Wishlist<span class="text-dark">({{ $wishlistCount }})</span></a>
                </div>
            </div>
        </nav>
        <h1 class="text-center mb-3 mt-5">Wishlist</h1>
        <div class="product-container">
            <table class="table table-bordered">
                <thead>
                    <tr>
                        <th scope="col" style="width: 40%;">Product Name</th>
                        <th scope="col" style="width: 15%;" class="text-center">Quantity</th>
                        <th scope="col" style="width: 15%;" class="text-end">Price</th>
                        <th scope="col" class="text-center">Action</th>
                    </tr>
                </thead>
                <tbody>

                    @foreach ($wishlistItems as $k => $wishlist)
                    <tr>
                        <td>{{ $wishlist['name'] }}</td>
                        <td class="text-center">
                            {{ $wishlist['quantity'] }}
                        </td>
                        <td class="text-end">${{ number_format($wishlist['price'],2) }}</td>
                        <td class="text-center">
                            <button class="btn btn-outline-primary back-to-cart" data-product-id="{{ $wishlist->id }}"><span class="add-text">Putback to cart</span><span class="d-none adding-text"> Adding</span> <span class="d-none added-text"> Added</span></button>
                            <button class="btn btn-outline-danger remove-wishlist" data-product-id="{{ $wishlist->id }}"><span class="remove-text">Remove</span><span class="d-none removing-text"> Removing</span> <span class="d-none removed-text"> Removed</span></button>
                        </td>
                        <input type="hidden" value="{{ $wishlist['quantity'] }}" class="quantity-input">
                    </tr>
                    @endforeach

                </tbody>
            </table>
        </div>

    </div>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script>
        $('.back-to-cart').on('click', function() {
            var button = $(this);
            var productId = $(this).data('product-id');
            var quantity = $(this).closest('tr').find('.quantity-input').val();

            button.find('.add-text').addClass('d-none');
            button.find('.adding-text').removeClass('d-none');

            // Make an AJAX request to remove the product to the cart
            $.ajax({
                type: 'POST',
                url: '{{ route('backToCart') }}',
                data: {
                    product_id: productId,
                    quantity: quantity,
                    _token: '{{ csrf_token() }}',
                },
                success: function(response) {
                    button.find('.adding-text').addClass('d-none');
                    button.find('.added-text').removeClass('d-none');
                    if (response.redirect_url) {
                        // Perform the redirect
                        window.location.href = response.redirect_url;
                    }
                },
                error: function(error) {
                    console.error('Error adding product to cart:', error);
                }
            });
        });
        $('.remove-wishlist').on('click', function() {
            var button = $(this);
            var productId = $(this).data('product-id');

            button.find('.remove-text').addClass('d-none');
            button.find('.removing-text').removeClass('d-none');

            // Make an AJAX request to remove the product to the cart
            $.ajax({
                type: 'POST',
                url: '{{ route('removeFromWishlist') }}',
                data: {
                    product_id: productId,
                    _token: '{{ csrf_token() }}',
                },
                success: function(response) {
                    button.find('.removing-text').addClass('d-none');
                    button.find('.removed-text').removeClass('d-none');
                    location.reload();
                },
                error: function(error) {
                    console.error('Error adding product to cart:', error);
                }
            });
        });
    </script>
</body>

</html>